@@ -1,6 +1,6 @@
 /*
 fullquottel - a program that helps to distinguish whether an email has the "tofu" style.
-Copyright (C) 2005 Toastfreeware <toast@toastfreeware.priv.at> - 
+Copyright (C) 2005-2012 Toastfreeware <toast@toastfreeware.priv.at> - 
 Philipp Spitzer and Gregor Herrmann
 
 This program is free software; you can redistribute it and/or modify
@@ -157,36 +157,36 @@ typedef multimap<string, string> MultiMap;
 // Command line parsing
 // --------------------
 
-const char *argp_program_version = "fullquottel 0.1.2";
+const char *argp_program_version = "fullquottel 0.1.3";
 const char *argp_program_bug_address = "<toast@toastfreeware.priv.at>";
 static char doc[] = "fullquottel - tool for detecting full quotes in mails or postings";
 static char args_doc[] = "< infile > outfile";
 static struct argp_option argp_options[] = {
-  {"scorethreshold",    				't', "NUMBER",  0,  "Threshold for final score that discriminates between Goodquottel and Fullquottel (default: 1.5)", 0 },
-  {"quotechars",    					-1,  "CHARS",   0,  "Chars used for quoting (default: >|#)", 1 },
-  {"debug",         					'd', 0,   		0,  "Debug option (prints single test results; default: off)", 2 },
-  {"ownsigtest",    					-10, "1|0",   	0,  "Turn on/off ownSigTest (default: on)", 10 },
-  {"ownsigtestscore",    				-11, "NUMBER",  0,  "Score for ownSigTest (default: 1.0)", 11 },
-  {"ownsigtestfile",       				'f', "SIGFILE", 0,  "Signature file to test against (default: ~/.signature)", 12 },
-  {"mstest",    						-20, "1|0",   	0,  "Turn on/off msTest (Microsoft attribution lines; default: on)", 20 },
-  {"mstestscore",    					-21, "NUMBER",  0,  "Score for msTest (default: 1.0)", 21 },
-  {"mstestthreshold",    				-22, "NUMBER",  0,  "Threshold for msTest (at or below which line a Microsoft attribution line ist found; default: 2)", 22 },
-  {"quotedtoalltest",    				-30, "1|0",   	0,  "Turn on/off quotedToAllTest (ratio quoted lines to all; default: on)", 30 },
-  {"quotedtoalltestscore",    			-31, "NUMBER",  0,  "Score for quotedToAllTest (default: 1.0)", 31 },
-  {"quotedtoalltestfactor",    			-32, "NUMBER",  0,  "Result = score + ratio * FACTOR (default: 0)", 32 },
-  {"quotedtoalltestthreshold",    		-33, "NUMBER",  0,  "Ratio threshold for activating quotedToAllTest (default: 0.5)", 33 },
-  {"bottomquotedtoalltest",    			-40, "1|0",   	0,  "Turn on/off bottomQuotedToAllTest (ratio quoted lines at bottom to all; default: on)", 40 },
-  {"bottomquotedtoalltestscore",    	-41, "NUMBER",  0,  "Score for bottomQuotedToAllTest (default: 1.0)", 41 },
-  {"bottomquotedtoalltestfactor",    	-42, "NUMBER",  0,  "Result = score + ratio * FACTOR (default: 0)", 42 },
-  {"bottomquotedtoalltestthreshold",    -43, "NUMBER",  0,  "Ratio threshold for activating bottomQuotedToAllTest (default: 0.5)", 43 },
-  {"bottomquotedtoquotedtest",    		-50, "1|0",   	0,  "Turn on/off bottomQuotedToQuotedTest (ratio quoted lines at bottom to all quoted lines; default: on)", 50 },
-  {"bottomquotedtoquotedtestscore",     -51, "NUMBER",  0,  "Score for bottomQuotedToQuotedTest (default: 1.0)", 51 },
-  {"bottomquotedtoquotedtestfactor",    -52, "NUMBER",  0,  "Result = score + ratio * FACTOR (default: 0)", 52 },
-  {"bottomquotedtoquotedtestthreshold", -53, "NUMBER",  0,  "Ratio threshold for activating bottomQuotedToQuotedTest (default: 0.5)", 53 },
-  {"singlebottomquotetest",    			-60, "1|0",   	0,  "Turn on/off singleBottomQuoteTest (only one quote block, and at the bottom; default: on)", 60 },
-  {"singlebottomquotetestscore",    	-61, "NUMBER",  0,  "Score for singleBottomQuoteTest (default: 1.0)", 61 },
-  {"\nHINT: All long options (without leading --) can be used in ~/.fullquottelrc\n",	-70, 0,	OPTION_DOC, "", 70 },
-  { 0 }
+	{"scorethreshold",                    't', "NUMBER",  0,  "Threshold for final score that discriminates between Goodquottel and Fullquottel (default: 1.5)", 0 },
+	{"quotechars",                         -1,  "CHARS",  0,  "Chars used for quoting (default: >|#)", 1 },
+	{"debug",                             'd', 0,         0,  "Debug option (prints single test results; default: off)", 2 },
+	{"ownsigtest",                        -10, "1|0",     0,  "Turn on/off ownSigTest (default: on)", 10 },
+	{"ownsigtestscore",                   -11, "NUMBER",  0,  "Score for ownSigTest (default: 1.0)", 11 },
+	{"ownsigtestfile",                    'f', "SIGFILE", 0,  "Signature file to test against (default: ~/.signature)", 12 },
+	{"mstest",                            -20, "1|0",     0,  "Turn on/off msTest (Microsoft attribution lines; default: on)", 20 },
+	{"mstestscore",                       -21, "NUMBER",  0,  "Score for msTest (default: 1.0)", 21 },
+	{"mstestthreshold",                   -22, "NUMBER",  0,  "Threshold for msTest (at or below which line a Microsoft attribution line ist found; default: 2)", 22 },
+	{"quotedtoalltest",                   -30, "1|0",     0,  "Turn on/off quotedToAllTest (ratio quoted lines to all; default: on)", 30 },
+	{"quotedtoalltestscore",              -31, "NUMBER",  0,  "Score for quotedToAllTest (default: 1.0)", 31 },
+	{"quotedtoalltestfactor",             -32, "NUMBER",  0,  "Result = score + ratio * FACTOR (default: 0)", 32 },
+	{"quotedtoalltestthreshold",          -33, "NUMBER",  0,  "Ratio threshold for activating quotedToAllTest (default: 0.5)", 33 },
+	{"bottomquotedtoalltest",             -40, "1|0",     0,  "Turn on/off bottomQuotedToAllTest (ratio quoted lines at bottom to all; default: on)", 40 },
+	{"bottomquotedtoalltestscore",        -41, "NUMBER",  0,  "Score for bottomQuotedToAllTest (default: 1.0)", 41 },
+	{"bottomquotedtoalltestfactor",       -42, "NUMBER",  0,  "Result = score + ratio * FACTOR (default: 0)", 42 },
+	{"bottomquotedtoalltestthreshold",    -43, "NUMBER",  0,  "Ratio threshold for activating bottomQuotedToAllTest (default: 0.5)", 43 },
+	{"bottomquotedtoquotedtest",          -50, "1|0",     0,  "Turn on/off bottomQuotedToQuotedTest (ratio quoted lines at bottom to all quoted lines; default: on)", 50 },
+	{"bottomquotedtoquotedtestscore",     -51, "NUMBER",  0,  "Score for bottomQuotedToQuotedTest (default: 1.0)", 51 },
+	{"bottomquotedtoquotedtestfactor",    -52, "NUMBER",  0,  "Result = score + ratio * FACTOR (default: 0)", 52 },
+	{"bottomquotedtoquotedtestthreshold", -53, "NUMBER",  0,  "Ratio threshold for activating bottomQuotedToQuotedTest (default: 0.5)", 53 },
+	{"singlebottomquotetest",             -60, "1|0",     0,  "Turn on/off singleBottomQuoteTest (only one quote block, and at the bottom; default: on)", 60 },
+	{"singlebottomquotetestscore",        -61, "NUMBER",  0,  "Score for singleBottomQuoteTest (default: 1.0)", 61 },
+	{"\nHINT: All long options (without leading --) can be used in ~/.fullquottelrc\n",    -70, 0,    OPTION_DOC, "", 70 },
+	{ 0 }
 };
 
 
@@ -348,7 +348,7 @@ static error_t parse_opt(int key, char *arg, struct argp_state *state) {
 	if (arg) s = arg;
 	istringstream ist(s); 
 	switch (key) {
-    case 't': ist >> options->scoreThreshold; break;
+	case 't': ist >> options->scoreThreshold; break;
 	case -1:  options->quoteChars = arg; break;
 	case 'd': options->debug = true; break;
 	case -10: ist >> options->ownSigTest.active; break;
@@ -375,14 +375,14 @@ static error_t parse_opt(int key, char *arg, struct argp_state *state) {
 
 	case ARGP_KEY_ARG:
 		if (state->arg_num > 0)
-        // we have no arguments
-        argp_usage (state);
+		// we have no arguments
+		argp_usage (state);
 		break;
 
 	default:
-		return ARGP_ERR_UNKNOWN;
+		return (error_t)ARGP_ERR_UNKNOWN;
 	}
-	return 0;
+	return (error_t)0;
 }
 
 
